### 22. REALIGNMENT	AND	TRANSFORMATION	PROGRAMS

In	the	second	quarter	of	2020,	we	identified	and	initiated	certain	realignment	activities	resulting	from	our	Flowserve	2.0	Transformation	Program (defined	 below)	 to	 right-size	 our	 organizational	 operations	 based	 on	 the	 current	 business	 environment,	 with	 the	 overall	 objective	 to	 reduce	 our workforce	costs,	including	manufacturing	optimization	through	the	consolidation	of	certain	facilities	("2020	Realignment	Program").	The	realignment activities	 consist	 of	 restructuring	 and	 non-restructuring	 charges.	 Restructuring	 charges	 represent	 costs	 associated	 with	 the	 relocation	 of	 certain business	activities	and	facility	closures	and	include	related	severance	costs.	Non-restructuring	charges	are	primarily	employee	severance	associated with	the	workforce	reductions.	Expenses	are	primarily	reported	in	cost	of	sales	("COS")	or	selling,	general	and	administrative	("SG&amp;A"),	as	applicable, in	our	consolidated	statements	of	income.	We	anticipate	a	total	investment	in	these	initiated	realignment	activities	of	approximately	$80	million	and that	the	majority	of	the	charges	were	incurred	in	2020	with	the	remainder	to	be	incurred	in	early	2021.	There	are	certain	other	realignment	activities that	are	currently	being	evaluated,	but	have	not	yet	been	finalized.	The	realignment	programs	initiated	in	2015	("2015	Realignment	Programs"), which	consisted	of	both	restructuring	and	non-restructuring	charges,	were	substantially	complete	as	of	March	31,	2020,	resulting	in	$362.4	million	of total	charges	incurred	through	the	completion	of	the	programs.

In	the	second	quarter	of	2018,	we	launched	and	committed	resources	to	our	Flowserve	2.0	Transformation	("Flowserve	2.0	Transformation"),	a program	designed	to	transform	our	business	model	to	drive	operational	excellence,	reduce	complexity,	accelerate	growth,	improve	organizational health	 and	 better	 leverage	 our	 existing	 global	 platform.	 The	 Flowserve	 2.0	 Transformation	 expenses	 incurred	 primarily	 consist	 of	 professional services,	project	management	and	related	travel	costs	recorded	in	SG&amp;A.

Generally,	 the	 aforementioned	 charges	 will	 be	 paid	 in	 cash,	 except	 for	 asset	 write-downs,	 which	 are	 non-cash	 charges.	 The	 following	 is	 a summary	of	total	charges,	net	of	adjustments,	related	to	our	realignment	activities	and	Flowserve	2.0	Transformation	charges.	Realignment	charges incurred	in	2020	related	to	our	2020	Realignment	Program	and	realignment	charges	incurred	in	2019	related	to	our	2015	Realignment	Programs:

112